==> operation-prime-2.0.0-20140317.101053-26-sources.jar: org/gcube/data/analysis/tabulardata/operation/validation/DuplicateValuesInColumnValidatorFactory.java <==
package org.gcube.data.analysis.tabulardata.operation.validation;

import java.util.ArrayList;
import java.util.List;

import javax.inject.Inject;
import javax.inject.Singleton;

import org.gcube.data.analysis.tabulardata.cube.CubeManager;
import org.gcube.data.analysis.tabulardata.cube.data.connection.DatabaseConnectionProvider;
import org.gcube.data.analysis.tabulardata.operation.OperationId;
import org.gcube.data.analysis.tabulardata.operation.factories.types.ColumnValidatorFactory;
import org.gcube.data.analysis.tabulardata.operation.invocation.OperationInvocation;
import org.gcube.data.analysis.tabulardata.operation.parameters.Parameter;
import org.gcube.data.analysis.tabulardata.operation.worker.Worker;
import org.gcube.data.analysis.tabulardata.operation.worker.exceptions.InvalidInvocationException;

@Singleton
public class DuplicateValuesInColumnValidatorFactory extends ColumnValidatorFactory {

	private static final List<Parameter> parameters = new ArrayList<Parameter>();
	
	private static final OperationId OPERATION_ID = new OperationId(5004);
	
	private CubeManager cubeManager;

	private DatabaseConnectionProvider connectionProvider;

	
	
	@Inject
	public DuplicateValuesInColumnValidatorFactory(CubeManager cubeManager,
			DatabaseConnectionProvider connectionProvider) {
		super();
		this.cubeManager = cubeManager;
		this.connectionProvider = connectionProvider;
	}

	@Override
	public Worker createWorker(OperationInvocation invocation)
			throws InvalidInvocationException {
		performBaseChecks(invocation);
		return new DuplicateValuesInColumnValidator(invocation, cubeManager, connectionProvider);
	}

	@Override
	protected String getOperationName() {
		return "Duplicate Values in Column Validator";
	}

	@Override
	protected String getOperationDescription() {
		return "Checks for duplicate values in selected column.";
	}

	@Override
	protected List<Parameter> getParameters() {
		return parameters;
	}
	
	@Override
	protected OperationId getOperationId() {
		return OPERATION_ID;
	}
	
}

==> operation-prime-2.0.5-20140327.172558-1-sources.jar: org/gcube/data/analysis/tabulardata/operation/validation/DuplicateValuesInColumnValidatorFactory.java <==
package org.gcube.data.analysis.tabulardata.operation.validation;

import java.util.ArrayList;
import java.util.List;

import javax.inject.Inject;
import javax.inject.Singleton;

import org.gcube.data.analysis.tabulardata.cube.CubeManager;
import org.gcube.data.analysis.tabulardata.cube.data.connection.DatabaseConnectionProvider;
import org.gcube.data.analysis.tabulardata.operation.OperationId;
import org.gcube.data.analysis.tabulardata.operation.factories.types.ColumnValidatorFactory;
import org.gcube.data.analysis.tabulardata.operation.invocation.OperationInvocation;
import org.gcube.data.analysis.tabulardata.operation.parameters.Parameter;
import org.gcube.data.analysis.tabulardata.operation.worker.Worker;
import org.gcube.data.analysis.tabulardata.operation.worker.exceptions.InvalidInvocationException;

@Singleton
public class DuplicateValuesInColumnValidatorFactory extends ColumnValidatorFactory {

	private static final List<Parameter> parameters = new ArrayList<Parameter>();
	
	private static final OperationId OPERATION_ID = new OperationId(5004);
	
	private CubeManager cubeManager;

	private DatabaseConnectionProvider connectionProvider;

	
	
	@Inject
	public DuplicateValuesInColumnValidatorFactory(CubeManager cubeManager,
			DatabaseConnectionProvider connectionProvider) {
		super();
		this.cubeManager = cubeManager;
		this.connectionProvider = connectionProvider;
	}

	@Override
	public Worker createWorker(OperationInvocation invocation)
			throws InvalidInvocationException {
		performBaseChecks(invocation,cubeManager);
		return new DuplicateValuesInColumnValidator(invocation, cubeManager, connectionProvider);
	}

	@Override
	protected String getOperationName() {
		return "Duplicate Values in Column Validator";
	}

	@Override
	protected String getOperationDescription() {
		return "Checks for duplicate values in selected column.";
	}

	@Override
	protected List<Parameter> getParameters() {
		return parameters;
	}
	
	@Override
	protected OperationId getOperationId() {
		return OPERATION_ID;
	}
	
}
